Processors
==========

.. automodule:: burdoc.processors
   :members:

.. toctree::
   :maxdepth: 1

   processor
   aggregator_processor
   heading_processor
   json_out_processor
   layout_processor
   list_processor
   margin_processor
   pdf_load_processor
   reading_order_processor
   table_processors
   
